@@ -1,24 +1,23 @@
-import copy
-import operator
-from zope import interface
+# -*- coding: utf-8 -*-
+from plone.schemaeditor import schema as se_schema
+from plone.schemaeditor import _
+from plone.schemaeditor import interfaces
+from plone.schemaeditor.interfaces import IFieldFactory
+from z3c.form import validator
 from zope import component
-from zope.component import adapter
+from zope import interface
+from zope import schema
 from zope.component import getUtilitiesFor
 from zope.globalrequest import getRequest
-from zope.interface import implementer
 from zope.i18n import translate
-from zope import schema
+from zope.interface import implementer
+from zope.lifecycleevent.interfaces import IObjectAddedEvent
 from zope.schema import interfaces as schema_ifaces
 from zope.schema import vocabulary
 from zope.schema.vocabulary import SimpleVocabulary
-from zope.lifecycleevent.interfaces import IObjectAddedEvent
 
-from z3c.form import validator
-
-from plone.schemaeditor.interfaces import IFieldFactory
-from plone.schemaeditor import _
-from plone.schemaeditor import interfaces
-from plone.schemaeditor import schema as se_schema
+import copy
+import operator
 
 
 @interface.implementer(interfaces.IFieldEditFormSchema)
@@ -62,12 +61,16 @@ def FieldsVocabularyFactory(context):
     field_factories = getUtilitiesFor(IFieldFactory)
     if context.allowedFields is not None:
         field_factories = [(id, factory) for id, factory in field_factories
-                            if id in context.allowedFields]
+                           if id in context.allowedFields]
     terms = []
     for (field_id, factory) in field_factories:
-        terms.append(SimpleVocabulary.createTerm(factory,
-                                                 factory.title,
-                                                 translate(factory.title, context=request)))
+        terms.append(
+            SimpleVocabulary.createTerm(
+                factory,
+                factory.title,
+                translate(factory.title, context=request)
+            )
+        )
     terms = sorted(terms, key=operator.attrgetter('title'))
     return SimpleVocabulary(terms)
 
@@ -106,25 +109,39 @@ ChoiceFactory = FieldFactory(
 
 
 @interface.implementer(se_schema.ITextLineChoice)
+@component.adapter(schema_ifaces.IChoice)
 class TextLineChoiceField(object):
-    component.adapts(schema_ifaces.IChoice)
 
     def __init__(self, field):
         self.__dict__['field'] = field
 
     def __getattr__(self, name):
         if name == 'values':
-            return [term.value for term in (self.field.vocabulary or [])]
+            values = []
+            for term in (self.field.vocabulary or []):
+                if term.value != term.title:
+                    values.append(u'{0:s}|{1:s}'.format(
+                        term.value, term.title))
+                else:
+                    values.append(term.value)
+            return values
+
 
         return getattr(self.field, name)
 
     def _constructVocabulary(self, value):
         terms = []
         if value:
-            for value in value:
+            for item in value:
+                if item and u'|' in item:
+                    voc_value, voc_title = item.split(u'|', 1)
+                else:
+                    voc_value = item
+                    voc_title = item
+
                 term = vocabulary.SimpleTerm(
-                    token=value.encode('unicode_escape'),
-                    value=value, title=value)
+                    token=voc_value.encode('unicode_escape'),
+                    value=voc_value, title=voc_title)
                 terms.append(term)
 
         return vocabulary.SimpleVocabulary(terms)
@@ -152,13 +169,13 @@ class TextLineChoiceField(object):
         return delattr(self.field, name)
 
 
+@component.adapter(interface.Interface, interface.Interface,
+                   interfaces.IFieldEditForm,
+                   se_schema.ITextLinesField, interface.Interface)
 class VocabularyValuesValidator(validator.SimpleFieldValidator):
 
     """Ensure duplicate vocabulary terms are not submitted
     """
-    component.adapts(interface.Interface, interface.Interface,
-                     interfaces.IFieldEditForm,
-                     se_schema.ITextLinesField, interface.Interface)
 
     def validate(self, values):
         if values is None:
@@ -173,14 +190,16 @@ class VocabularyValuesValidator(validator.SimpleFieldValidator):
             if term.value in by_value:
                 raise interface.Invalid(
                     _('field_edit_error_conflicting_values',
-                      default=u"The '${value1}' vocabulary value conflicts with '${value2}'.",
+                      default=u"The '${value1}' vocabulary value conflicts "
+                              u"with '${value2}'.",
                       mapping={'value1': value,
                                'value2': by_value[term.value].value}))
 
             if term.token in by_token:
                 raise interface.Invalid(
                     _('field_edit_error_conflicting_values',
-                      default=u"The '${value1}' vocabulary value conflicts with '${value2}'.",
+                      default=u"The '${value1}' vocabulary value conflicts "
+                              u"with '${value2}'.",
                       mapping={'value1': value,
                                'value2': by_value[term.token].value}))
 
@@ -203,11 +222,15 @@ class VocabularyNameValidator(validator.SimpleFieldValidator):
         if values and self.request.form.get('form.widgets.values', None):
             raise interface.Invalid(
                 _('field_edit_error_values_and_name',
-                  default=u"You can't set a vocabulary name AND vocabulary values. "
-                          u"Please clear values field or set no value here."))
+                  default=u'You can not set a vocabulary name AND vocabulary '
+                          u'values. Please clear values field or set no value '
+                          u'here.'
+                  )
+            )
 
         return super(VocabularyNameValidator, self).validate(values)
 
+
 validator.WidgetValidatorDiscriminators(
     VocabularyNameValidator,
     field=se_schema.ITextLineChoice['vocabularyName'])
@@ -226,8 +249,8 @@ MultiChoiceFactory = FieldFactory(
 
 
 @interface.implementer_only(se_schema.ITextLineChoice)
+@component.adapter(schema_ifaces.ISet)
 class TextLineMultiChoiceField(TextLineChoiceField):
-    component.adapts(schema_ifaces.ISet)
 
     def __init__(self, field):
         self.__dict__['field'] = field
@@ -235,10 +258,17 @@ class TextLineMultiChoiceField(TextLineChoiceField):
     def __getattr__(self, name):
         field = self.field
         if name == 'values':
-            return [term.value
-                    for term in (field.value_type.vocabulary or [])]
+            values = []
+            for term in (self.field.value_type.vocabulary or []):
+                if term.value != term.title:
+                    values.append(u'{0:s}|{1:s}'.format(
+                        term.value, term.title))
+                else:
+                    values.append(term.value)
+            return values
         elif name == 'vocabularyName':
-            return getattr(field.value_type, name, None) or getattr(field, name)
+            return getattr(field.value_type, name, None) or \
+                   getattr(field, name)
         else:
             return getattr(field, name)
 
@@ -262,7 +292,7 @@ class TextLineMultiChoiceField(TextLineChoiceField):
 
 
 # make Bool fields use the radio widget by default
-@adapter(schema_ifaces.IBool, IObjectAddedEvent)
+@component.adapter(schema_ifaces.IBool, IObjectAddedEvent)
 def setBoolWidget(field, event):
     schema = field.interface
     widgets = schema.queryTaggedValue('plone.autoform.widgets', {})
