@@ -1,23 +1,31 @@
-import re
-from zope.component.interfaces import IObjectEvent
-from zope.interface import Invalid, invariant
-from zope.interface.interfaces import Interface, IInterface, Attribute
-from zope.publisher.interfaces.browser import IBrowserPage
-from zope.schema import Object, TextLine, Text, Choice, ASCIILine, Bool
-from zope.schema.interfaces import IField
-from z3c.form.interfaces import IEditForm
+# -*- coding: utf-8 -*-
 from OFS.interfaces import IItem
 from plone.schemaeditor import _
+from z3c.form.interfaces import IEditForm
+from zope.component.interfaces import IObjectEvent
+from zope.interface import Invalid
+from zope.interface import invariant
+from zope.interface.interfaces import Attribute
+from zope.interface.interfaces import IInterface
+from zope.interface.interfaces import Interface
+from zope.publisher.interfaces.browser import IBrowserPage
+from zope.schema import ASCIILine
+from zope.schema import Bool
+from zope.schema import Choice
+from zope.schema import Object
+from zope.schema import Text
+from zope.schema import TextLine
+from zope.schema.interfaces import IField
+
+import re
 
 
 class ISchemaView(IBrowserPage):
-
     """ A publishable view of a zope 3 schema
     """
 
 
 class ISchemaContext(IItem):
-
     """ A publishable wrapper of a zope 3 schema
     """
 
@@ -38,11 +46,11 @@ class ISchemaContext(IItem):
 
     fieldsWhichCannotBeDeleted = Attribute(
         """List of field names that may not be deleted from this schema."""
-        )
+    )
 
     enableFieldsets = Attribute(
         """Enable extra fieldsets."""
-        )
+    )
 
 
 class ISchemaModifiedEvent(IObjectEvent):
@@ -53,7 +61,6 @@ class ISchemaModifiedEvent(IObjectEvent):
 
 
 class IFieldContext(IItem):
-
     """ A publishable wrapper of a zope 3 schema field
     """
 
@@ -63,14 +70,11 @@ class IFieldContext(IItem):
 
 
 class IFieldEditorExtender(IInterface):
-
     """ An additional schema for use when editing a field."""
 
 
 class IFieldFactory(IField):
-
-    """ A component that instantiates a field when called.
-    """
+    """ A component that instantiates a field when called."""
     title = TextLine(title=u'Title')
 
     def available(self):
@@ -84,14 +88,14 @@ class IFieldFactory(IField):
 
 
 class IEditableSchema(Interface):
-
     """ Interface for adding/removing fields to/from a schema.
     """
 
     def addField(field, name=None):
         """ Add a field to a schema
 
-            If not provided, the field's name will be taken from its __name__ attribute.
+        If not provided, the field's name will be taken from its __name__
+        attribute.
         """
 
     def removeField(field_name):
@@ -99,11 +103,13 @@ class IEditableSchema(Interface):
         """
 
     def moveField(field_name, new_pos):
-        """ Move a field to the (new_pos)th position in the schema's sort order (indexed beginning
-            at 0).
+        """ Move a field to the (new_pos)th position in the schema's sort ç
+        order (indexed beginning at 0).
 
-            Schema fields are assigned an 'order' attribute that increments for each new field
-            instance.  We shuffle these around in case it matters anywhere that they're unique.
+        Schema fields are assigned an 'order' attribute that increments for
+        each new field instance.
+        We shuffle these around in case it matters anywhere that they're
+        unique.
         """
 
     def changeFieldFieldset(field_name, next_fieldset):
@@ -113,19 +119,24 @@ class IEditableSchema(Interface):
 
 
 class IFieldEditForm(IEditForm):
-
     """ Marker interface for field edit forms
     """
 
 
 class IFieldEditFormSchema(Interface):
-
     """ The schema describing the form fields for a field.
     """
 
+
 RESERVED_NAMES = (
-    "subject", "format", "language", "creators", "contributors", "rights",
-    "effective_date", "expiration_date"
+    'subject',
+    'format',
+    'language',
+    'creators',
+    'contributors',
+    'rights',
+    'effective_date',
+    'expiration_date',
 )
 
 # a letter followed by letters, numbers, or underscore
@@ -135,7 +146,9 @@ ID_RE = re.compile(r'^[a-z][\w\d\.]*$')
 def isValidFieldName(value):
     if not ID_RE.match(value):
         raise Invalid(
-            _(u'Please use only letters, numbers and the following characters: _.'))
+            _(u'Please use only letters, numbers and the following '
+              u'characters: _.')
+        )
     if value in RESERVED_NAMES:
         raise Invalid(
             _(u"'${name}' is a reserved field name.", mapping={'name': value}))
@@ -163,28 +176,36 @@ class INewField(Interface):
     )
 
     factory = Choice(
-        title=_(u"Field type"),
-        vocabulary="Fields",
+        title=_(u'Field type'),
+        vocabulary='Fields',
         required=True,
         # This can't be done yet or we'll create circular import problem.
         # So it will be injected from fields.py
         # default=TextLineFactory,
     )
 
-    required = Bool(title=_(u"Required field"),
-                    description=_(u'Check this box if you want this field to be required.'),
-                    default=False,
-                    required=False)
+    required = Bool(
+        title=_(u'Required field'),
+        description=_(
+            u'Check this box if you want this field to be required.'
+        ),
+        default=False,
+        required=False,
+    )
 
     @invariant
     def checkTitleAndDescriptionTypes(data):
         if data.__name__ is not None and data.factory is not None:
-            if data.__name__ == 'title' and data.factory.fieldcls is not TextLine:
+            if data.__name__ == 'title' and \
+                    data.factory.fieldcls is not TextLine:
                 raise Invalid(
-                    _(u"The 'title' field must be a Text line (string) field."))
-            if data.__name__ == 'description' and data.factory.fieldcls is not Text:
+                    _(u"The 'title' field must be a Text line (string) field.")
+                )
+            if data.__name__ == 'description' and \
+                    data.factory.fieldcls is not Text:
                 raise Invalid(
-                    _(u"The 'description' field must be a Text field."))
+                    _(u"The 'description' field must be a Text field.")
+                )
 
 
 class INewFieldset(Interface):
